@@ -9,6 +9,7 @@ import io
 import sys
 import time
 import grpc
+import semantic_version
 import types
 import platform
 from google.protobuf import json_format
@@ -40,6 +41,7 @@ def api(
     logger=None,
     loglevel=logging.INFO,
     ext=None,
+    version_check=False,
 ):
     """Create an instance of an Api class
 
@@ -675,7 +677,22 @@ class OpenApiObject(OpenApiBase, OpenApiValidator):
         return self._properties[name]
 
     def _set_property(self, name, value, choice=None):
-        if name in self._DEFAULTS and value is None:
+        if name == "choice":
+
+            if (
+                self.parent is None
+                and value is not None
+                and value not in self._TYPES["choice"]["enum"]
+            ):
+                raise Exception(
+                    "%s is not a valid choice, valid choices are %s"
+                    % (value, ", ".join(self._TYPES["choice"]["enum"]))
+                )
+
+            self._set_choice(value)
+            if name in self._DEFAULTS and value is None:
+                self._properties[name] = self._DEFAULTS[name]
+        elif name in self._DEFAULTS and value is None:
             self._set_choice(name)
             self._properties[name] = self._DEFAULTS[name]
         else:
@@ -969,6 +986,7 @@ class OpenApiIter(OpenApiBase):
         if (
             self._GETITEM_RETURNS_CHOICE_OBJECT is True
             and found._properties.get("choice") is not None
+            and found._properties.get(found._properties["choice"]) is not None
         ):
             return found._properties[found._properties["choice"]]
         return found
